@@ -1007,6 +1007,15 @@ int Translator::TranslateLetter(char *word, char *phonemes, int control)
 		strcpy(phonemes,ph_buf);
 		return(0);
 	}
+	if(ph_buf[0] == 0)
+	{
+		// character name not found
+		if(iswalpha(letter))
+			Lookup("_?A",ph_buf);
+
+		if((ph_buf[0]==0) && !iswspace(letter))
+			Lookup("_??",ph_buf);
+	}
 
 	// at a stress marker at the start of the letter name, unless one is already marked
 	ph_stress[0] = phonSTRESS_P;
@@ -1675,6 +1684,15 @@ int Translator::TranslateWord2(char *word, int wflags, int pre_pause, int next_p
 			srcix = source_ix+1;
 		}
 		else
+		if(ph_code == phonX1)
+		{
+			// a language specific action 
+			if(langopts.param[LOPT_IT_DOUBLING])
+			{
+				flags |= FLAG_DOUBLING;
+			}
+		}
+		else
 		{
 			ph_list2[n_ph_list2].phcode = ph_code;
 			ph_list2[n_ph_list2].tone_number = 0;
@@ -1702,12 +1720,14 @@ int Translator::TranslateWord2(char *word, int wflags, int pre_pause, int next_p
 			}
 			else
 			{
-				if(first_phoneme && langopts.param[LOPT_IT_DOUBLING]
-					&& (end_stressed_vowel || (prev_dict_flags & FLAG_XX1)))
+				if(first_phoneme && langopts.param[LOPT_IT_DOUBLING])
 				{
-					// italian, double the initial consonant if the previous word ends with a
-					// stressed vowel, or is marked with a flag
-					ph_list2[n_ph_list2].synthflags |= SFLAG_LENGTHEN;
+					if((prev_dict_flags & FLAG_DOUBLING)  || (end_stressed_vowel && (langopts.param[LOPT_IT_DOUBLING] == 2)))
+					{
+						// italian, double the initial consonant if the previous word ends with a
+						// stressed vowel, or is marked with a flag
+						ph_list2[n_ph_list2].synthflags |= SFLAG_LENGTHEN;
+					}
 				}
 			}
 
